Tom Aarsen @tomaarsen

Location

  Nijmegen, Netherlands

Role

  Core Maintainer. Rewrote nltk.org, frequent issue triaging, bug fixing, and enhancements.

Active Range

  2020-

Joel Nothman @jnothman

Location

  Sydney, Australia

Role

  Metrics package maintainer, also responsible for nltk.tokenize.punkt, i.a.

Active Range

  2008-

Steven Bird @stevenbird

Location

  Darwin, Australia

Role

  Project lead, manager of NLTK Releases.

Active Range

  2001-

Alexis Dimitradis @alexisdimi

Location

  Utrecht, Netherlands

Role

  Manager of the NLTK mailing lists.

Danny Sepler @dannysepler

Role

  Maintainer, primarily involved with tests and quality assurance.

Active Range

  2020-

Dmitrijs Milajevs @dimazest

Location

  Oakland, USA

Role

  Maintainer, particularly involved with WSD, CoreNLP and DependencyGraphs.

Active Range

  2014-

Francis Bond @fcbond

Role

  Domain expert of WordNet.

Active Range

  2015-

Ilia Kurenkov @iliakur

Role

  Language models package maintainer. Also involved with tests and code quality.

Active Range

  2012-

purificant @purificant

Active Range

  2018-

Liling Tan @alvations

Location

  Saarbrucken, Germany

Active Range

  2014-